@@ -118,12 +118,17 @@ save_online_buddies (){
 
     if (!g_string_equal (buddies_str, str)){
 	fd = fopen (fd_name, "w");
-	fwrite (str->str, 1, str->len, fd);
-	fclose (fd);
+	if (fd){
+	    fwrite (str->str, 1, str->len, fd);
+	    fclose (fd);
+	    g_string_free (buddies_str, TRUE);
+	    buddies_str = str;
+	    gaim_debug_info ("nautilus", "save blist online\n");
+	}else{
+	    g_string_free (str, TRUE);
+	    gaim_debug_info ("nautilus", "don't save blist online. No change\n");
+	}
 	g_free (fd_name);
-	g_string_free (buddies_str, TRUE);
-	buddies_str = str;
-	gaim_debug_info ("nautilus", "save blist online\n");
     }else{
 	g_string_free (str, TRUE);
 	gaim_debug_info ("nautilus", "don't save blist online. No change\n");
